@@ -29,7 +29,6 @@ import org.kuali.rice.core.api.uif.RemotableAttributeField;
 import org.kuali.rice.core.api.util.ConcreteKeyValue;
 import org.kuali.rice.core.api.util.KeyValue;
 import org.kuali.rice.kew.api.KewApiConstants;
-import org.kuali.rice.kew.api.WorkflowRuntimeException;
 import org.kuali.rice.kew.api.document.attribute.DocumentAttribute;
 import org.kuali.rice.kew.api.document.attribute.DocumentAttributeFactory;
 import org.kuali.rice.kew.api.document.search.DocumentSearchCriteria;
@@ -56,8 +55,8 @@ import org.kuali.rice.kew.useroptions.UserOptionsService;
 import org.kuali.rice.kew.util.Utilities;
 import org.kuali.rice.kim.api.group.Group;
 import org.kuali.rice.kim.api.services.KimApiServiceLocator;
-import org.kuali.rice.kns.service.DictionaryValidationService;
 import org.kuali.rice.kns.service.DataDictionaryService;
+import org.kuali.rice.kns.service.DictionaryValidationService;
 import org.kuali.rice.kns.service.KNSServiceLocator;
 import org.kuali.rice.krad.util.GlobalVariables;
 
@@ -166,9 +165,15 @@ public class DocumentSearchServiceImpl implements DocumentSearchService {
     }
 
     @Override
-	public DocumentSearchResults lookupDocuments(String principalId, DocumentSearchCriteria criteria) {
-		DocumentSearchGenerator docSearchGenerator = getStandardDocumentSearchGenerator();
-		DocumentType documentType = KEWServiceLocator.getDocumentTypeService().findByNameCaseInsensitive(criteria.getDocumentTypeName());
+    public DocumentSearchResults lookupDocuments(String principalId, DocumentSearchCriteria criteria) {
+        return lookupDocuments(principalId, criteria, !StringUtils.isBlank(criteria.getSaveName()));//Default saveSearch to false from any interaction with this particular API unless a save name is provided
+    }
+
+
+    @Override
+    public DocumentSearchResults lookupDocuments(String principalId, DocumentSearchCriteria criteria, boolean saveSearch) {
+        DocumentSearchGenerator docSearchGenerator = getStandardDocumentSearchGenerator();
+        DocumentType documentType = KEWServiceLocator.getDocumentTypeService().findByNameCaseInsensitive(criteria.getDocumentTypeName());
         DocumentSearchCriteria.Builder criteriaBuilder = DocumentSearchCriteria.Builder.create(criteria);
         validateDocumentSearchCriteria(docSearchGenerator, criteriaBuilder);
         DocumentSearchCriteria builtCriteria = applyCriteriaCustomizations(documentType, criteriaBuilder.build());
@@ -188,7 +193,7 @@ public class DocumentSearchServiceImpl implements DocumentSearchService {
         List<RemotableAttributeField> searchFields = determineSearchFields(documentType);
         DocumentSearchResults.Builder searchResults = docSearchDao.findDocuments(docSearchGenerator, builtCriteria, criteriaModified, searchFields);
         if (documentType != null) {
-             // Pass in the principalId as part of searchCriteria to result customizers
+            // Pass in the principalId as part of searchCriteria to result customizers
             //TODO: The right way  to do this should have been to update the API for document customizer
 
             DocumentSearchCriteria.Builder docSearchUserIdCriteriaBuilder = DocumentSearchCriteria.Builder.create(builtCriteria);
@@ -231,9 +236,12 @@ public class DocumentSearchServiceImpl implements DocumentSearchService {
                 searchResults.setSearchResults(Collections.<DocumentSearchResult.Builder>emptyList());
             }
         }
-        saveSearch(principalId, builtCriteria);
+        if(saveSearch){
+            saveSearch(principalId, builtCriteria);
+        }
         return searchResults.build();
-	}
+    }
+
 
     protected void applyResultCustomization(DocumentSearchResult.Builder result, DocumentSearchResultValue value) {
         Map<String, List<DocumentAttribute.AbstractBuilder<?>>> customizedAttributeMap =
@@ -548,7 +556,7 @@ public class DocumentSearchServiceImpl implements DocumentSearchService {
 
     @Override
 	public List<KeyValue> getNamedSearches(String principalId) {
-		List<UserOptions> namedSearches = userOptionsService.findByUserQualified(principalId, NAMED_SEARCH_ORDER_BASE + "%");
+		List<UserOptions> namedSearches = new ArrayList<UserOptions>(userOptionsService.findByUserQualified(principalId, NAMED_SEARCH_ORDER_BASE + "%"));
 		List<KeyValue> sortedNamedSearches = new ArrayList<KeyValue>(0);
 		if (!namedSearches.isEmpty()) {
 			Collections.sort(namedSearches);
