@@ -1,5 +1,5 @@
 /**
- * Copyright 2005-2013 The Kuali Foundation
+ * Copyright 2005-2014 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ import java.util.List;
 public class TestRouteLevel {
 
     private int priority;
-    private List responsibilities = new ArrayList();
+    private List<TestResponsibility> responsibilities = new ArrayList();
     
     public int getPriority() {
         return priority;
@@ -32,10 +32,10 @@ public class TestRouteLevel {
     public void setPriority(int priority) {
         this.priority = priority;
     }
-    public List getResponsibilities() {
+    public List<TestResponsibility> getResponsibilities() {
         return responsibilities;
     }
-    public void setResponsibilities(List responsibilities) {
+    public void setResponsibilities(List<TestResponsibility> responsibilities) {
         this.responsibilities = responsibilities;
     }
     
