@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2013 The Kuali Foundation
+ * Copyright 2005-2014 The Kuali Foundation
  *
  * Licensed under the Educational Community License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -457,7 +457,7 @@ public class RuleManagementReferenceObjectBindingTest extends RuleManagementBase
 
         // find the two active ReferenceObjectBindings in the list
         query = QueryByCriteria.Builder.create();
-        query.setPredicates( equal("active","Y"), in("id", refObjBindingBuilderIds.toArray(new String[]{})));
+        query.setPredicates( equal("active", Boolean.TRUE), in("id", refObjBindingBuilderIds.toArray(new String[]{})));
 
         referenceObjectBindingIds = ruleManagementService.findReferenceObjectBindingIds(query.build());
         for (String referenceObjectBindingId : referenceObjectBindingIds ) {
