@@ -35,15 +35,7 @@ import org.springframework.web.multipart.MultipartFile;
 
 import javax.servlet.http.HttpServletRequest;
 import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Enumeration;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Properties;
-import java.util.Set;
-import java.util.UUID;
+import java.util.*;
 
 /**
  * Base form class for views within the KRAD User Interface Framework.
@@ -208,6 +200,8 @@ public class UifFormBase implements ViewModel {
     protected Map<String, Boolean> actionFlags;
     protected Map<String, Boolean> editModes;
 
+    protected String csrfToken;
+
     protected HttpServletRequest request;
 
     private Object dialogDataObject;
@@ -254,6 +248,9 @@ public class UifFormBase implements ViewModel {
             setRequestedFormKey(formKeyParam);
         }
 
+        String csrfToken = KRADServiceLocatorWeb.getCsrfService().getSessionToken(request);
+        setCsrfToken(csrfToken);
+
         this.request = request;
     }
 
@@ -1522,4 +1519,13 @@ public class UifFormBase implements ViewModel {
                 this.formKey).append(", requestedFormKey=").append(this.requestedFormKey).append("]");
         return builder.toString();
     }
+
+    public String getCsrfToken() {
+        return csrfToken;
+    }
+
+    public void setCsrfToken(String csrfToken) {
+        this.csrfToken = csrfToken;
+    }
+
 }
